@@ -27,7 +27,6 @@
 #include "seahorse-gpgme-keyring.h"
 #include "seahorse-gpgme-secret-deleter.h"
 #include "seahorse-gpgme-uid.h"
-#include "seahorse-pgp-actions.h"
 #include "seahorse-pgp-backend.h"
 #include "seahorse-pgp-key.h"
 
@@ -52,7 +51,7 @@ static void       seahorse_gpgme_key_deletable_iface       (SeahorseDeletableIfa
 
 static void       seahorse_gpgme_key_exportable_iface      (SeahorseExportableIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (SeahorseGpgmeKey, seahorse_gpgme_key, SEAHORSE_TYPE_PGP_KEY,
+G_DEFINE_TYPE_WITH_CODE (SeahorseGpgmeKey, seahorse_gpgme_key, SEAHORSE_PGP_TYPE_KEY,
                          G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_EXPORTABLE, seahorse_gpgme_key_exportable_iface);
                          G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_DELETABLE, seahorse_gpgme_key_deletable_iface);
 );
@@ -308,7 +307,6 @@ void
 seahorse_gpgme_key_realize (SeahorseGpgmeKey *self)
 {
 	SeahorseUsage usage;
-	GtkActionGroup *actions;
 	guint flags;
 
 	if (!self->pv->pubkey)
@@ -359,13 +357,10 @@ seahorse_gpgme_key_realize (SeahorseGpgmeKey *self)
 		usage = SEAHORSE_USAGE_PUBLIC_KEY;
 	}
 
-	actions = seahorse_gpgme_key_actions_instance ();
 	g_object_set (self,
 	              "usage", usage,
 	              "object-flags", flags,
-	              "actions", actions,
 	              NULL);
-	g_object_unref (actions);
 
 	seahorse_pgp_key_realize (SEAHORSE_PGP_KEY (self));
 }
