@@ -21,7 +21,6 @@
 
 #include "seahorse-gpgme.h"
 #include "seahorse-gpgme-uid.h"
-#include "seahorse-pgp.h"
 #include "seahorse-pgp-key.h"
 #include "seahorse-pgp-signature.h"
 
@@ -39,7 +38,7 @@ enum {
 	PROP_ACTUAL_INDEX
 };
 
-G_DEFINE_TYPE (SeahorseGpgmeUid, seahorse_gpgme_uid, SEAHORSE_TYPE_PGP_UID);
+G_DEFINE_TYPE (SeahorseGpgmeUid, seahorse_gpgme_uid, SEAHORSE_PGP_TYPE_UID);
 
 struct _SeahorseGpgmeUidPrivate {
 	gpgme_key_t pubkey;         /* The public key that this uid is part of */
