@@ -19,11 +19,8 @@
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
 
-#ifndef __SEAHORSE_KEYSERVER_SEARCH_H__
-#define __SEAHORSE_KEYSERVER_SEARCH_H__
+#pragma once
 
 #include <gtk/gtk.h>
 
 GtkWindow *  seahorse_keyserver_search_show      (GtkWindow *parent);
-
-#endif
