@@ -14,18 +14,15 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 /*
  * Various UI elements and dialogs used in pgp component.
  */
- 
-#ifndef __SEAHORSE_PGP_DIALOGS_H__
-#define __SEAHORSE_PGP_DIALOGS_H__
+
+#pragma once
 
 #include <gtk/gtk.h>
 
@@ -35,5 +32,3 @@ SeahorsePgpKey* seahorse_signer_get                 (GtkWindow *parent);
 
 GtkWindow *     seahorse_pgp_key_properties_show    (SeahorsePgpKey *pkey,
                                                      GtkWindow *parent);
-
-#endif /* __SEAHORSE_PGP_DIALOGS_H__ */
