@@ -17,8 +17,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __SEAHORSE_PGP_UID_H__
-#define __SEAHORSE_PGP_UID_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -26,13 +25,13 @@
 
 #include "seahorse-pgp-key.h"
 
-#define SEAHORSE_TYPE_PGP_UID            (seahorse_pgp_uid_get_type ())
+#define SEAHORSE_PGP_TYPE_UID            (seahorse_pgp_uid_get_type ())
 
-#define SEAHORSE_PGP_UID(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_PGP_UID, SeahorsePgpUid))
-#define SEAHORSE_PGP_UID_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_PGP_UID, SeahorsePgpUidClass))
-#define SEAHORSE_IS_PGP_UID(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_PGP_UID))
-#define SEAHORSE_IS_PGP_UID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_PGP_UID))
-#define SEAHORSE_PGP_UID_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_PGP_UID, SeahorsePgpUidClass))
+#define SEAHORSE_PGP_UID(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_PGP_TYPE_UID, SeahorsePgpUid))
+#define SEAHORSE_PGP_UID_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_PGP_TYPE_UID, SeahorsePgpUidClass))
+#define SEAHORSE_PGP_IS_UID(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_PGP_TYPE_UID))
+#define SEAHORSE_PGP_IS_UID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_PGP_TYPE_UID))
+#define SEAHORSE_PGP_UID_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_PGP_TYPE_UID, SeahorsePgpUidClass))
 
 typedef struct _SeahorsePgpUid SeahorsePgpUid;
 typedef struct _SeahorsePgpUidClass SeahorsePgpUidClass;
@@ -92,5 +91,3 @@ gchar*            seahorse_pgp_uid_calc_markup          (const gchar *name,
 
 GQuark            seahorse_pgp_uid_calc_id              (GQuark key_id,
                                                          guint index);
-
-#endif /* __SEAHORSE_PGP_UID_H__ */
